@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Server::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Server::VERSION = '0.124';
+  $App::DuckPAN::Cmd::Server::VERSION = '0.125';
 }
 # ABSTRACT: Starting up the webserver to test plugins
 
@@ -35,7 +35,7 @@ sub run {
 		'duckduck.js'               => { name => 'DuckDuckGo Javascript', file_path => '/duckduck.js' },
 		'handlebars.js'             => { name => 'Handlebars.js', file_path => '/js/handlebars-1.0.0-rc.3.js' },
 		'spice2_duckpan.js'         => { name => 'Spice2.js', file_path => '/spice2/spice2_duckpan.js' },
-		'spice2_duckpan_compile.js' => { name => 'Spice2 DuckPAN compile script', file_path => '/spice2/spice2_duckpan_compile.js' }
+		'duckpan.js'                => { name => 'Duckpan.js'},
 	);
 
 	my @blocks = @{$self->app->ddg->get_blocks_from_current_dir(@args)};
@@ -45,6 +45,7 @@ sub run {
 
 	foreach my $file_name (keys %spice_files){
 		copy(file(dist_dir('App-DuckPAN'),$file_name),file($self->app->cfg->cache_path,$file_name)) unless -f file($self->app->cfg->cache_path,$file_name);
+		next unless defined $spice_files{$file_name}{'file_path'};
 
 		my $path = $spice_files{$file_name}{'file_path'};
 		my $url = 'http://'.$hostname.''.$path;
@@ -77,7 +78,7 @@ sub run {
 	my $page_js = io(file($self->app->cfg->cache_path,'duckduck.js'))->slurp;
 	$page_js .= io(file($self->app->cfg->cache_path,'handlebars.js'))->slurp;
 	$page_js .= io(file($self->app->cfg->cache_path,'spice2_duckpan.js'))->slurp;
-	$page_js .= io(file($self->app->cfg->cache_path,'spice2_duckpan_compile.js'))->slurp;
+	$page_js .= io(file($self->app->cfg->cache_path,'duckpan.js'))->slurp;
 
 	print "\n\nStarting up webserver...";
 	print "\n\nYou can stop the webserver with Ctrl-C";
@@ -180,7 +181,7 @@ App::DuckPAN::Cmd::Server - Starting up the webserver to test plugins
 
 =head1 VERSION
 
-version 0.124
+version 0.125
 
 =head1 AUTHOR
 
